@@ -2,9 +2,10 @@ import ipywidgets
 from IPython.display import display,clear_output
 import numpy as np
 import json,os
-from py4xs.hdf import h5xs,h5sol_HT,h5sol_HPLC,lsh5,create_linked_files
 from py4xs.slnxs import trans_mode
 from py4xs.slnxs import get_font_size
+from py4xs.hdf import h5xs,lsh5,create_linked_files
+from lixtools.hdf import h5sol_HT,h5sol_HPLC
 from lixtools.atsas import gen_atsas_report
 import pylab as plt
 from scipy import interpolate,integrate
@@ -88,7 +89,8 @@ def display_solHT_data(fn, atsas_path=""):
     axr.append(fig2.add_axes([0.09, 0.25, 0.25, 0.6])) 
     axr.append(fig2.add_axes([0.41, 0.25, 0.25, 0.6])) 
     axr.append(fig2.add_axes([0.73, 0.25, 0.25, 0.6])) 
-                                 
+    axr.append(axr[0].twiny())
+    
     def onChangeSample(w):
         sn = ddSample.value
         sel = [sampleLabels[i] for i in range(len(sampleLabels)) 
